@@ -1,7 +1,7 @@
 package WWW::DistroWatch::ReleaseInfo;
 
 our $DATE = '2015-10-06'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,10 +103,10 @@ our $distros = do {
    "bridge"         => "Bridge",
    "cae"            => "CAELinux",
    "caine"          => "CAINE",
-   "caixamagica"    => "Caixa M\xC3\x83\xC2\xA1gica",
+   "caixamagica"    => "Caixa M\xE1gica",
    "calculate"      => "Calculate",
    "canaima"        => "Canaima",
-   "catix"          => "C\xC3\x83\xC2\xA0tix",
+   "catix"          => "C\xE0tix",
    "centos"         => "CentOS",
    "centrych"       => "Centrych",
    "chakra"         => "Chakra",
@@ -129,7 +129,7 @@ our $distros = do {
    "elastix"        => "Elastix",
    "elementary"     => "elementary",
    "elive"          => "Elive",
-   "emmabuntus"     => "Emmabunt\xC3\x83\xC2\xBCs",
+   "emmabuntus"     => "Emmabunt\xFCs",
    "endian"         => "Endian",
    "exe"            => "Exe",
    "exherbo"        => "Exherbo",
@@ -496,7 +496,7 @@ WWW::DistroWatch::ReleaseInfo - Get information about a distro's releases
 
 =head1 VERSION
 
-This document describes version 0.03 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2015-10-06.
+This document describes version 0.04 of WWW::DistroWatch::ReleaseInfo (from Perl distribution WWW-DistroWatch-ReleaseInfo), released on 2015-10-06.
 
 =head1 FUNCTIONS
 
